import {
  select,
  json,
  geoPath,
  geoAlbersUsa,
  geoMercator,
} from 'd3';
import { feature, mesh } from 'topojson';

// Select svg html element
const svg = select('svg');

// Define geo projection type as U.S.-centric composite projection
const projection = geoAlbersUsa();
const pathGenerator = geoPath().projection(projection);

// Read json and process data
json(
  'https://cdn.jsdelivr.net/npm/us-atlas@3.0.0/counties-10m.json'
).then((data) => {
  
  // get counties from json data
  const counties = feature(data, data.objects.counties);
  console.log(counties);
  console.log(data);
  
  // Update svg html element to add data such as title and counties to visualize in the screen
  svg
    .selectAll('path')
    .data(counties.features)
    .enter()
    .append('path')
    .attr('class', 'counties')
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text(d=>d.properties.name);
});
